==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvlogin-3.9.2-1.2.7.tar.gz: vlogin/setup.php <==
<?php

/**
  * SquirrelMail Login Manager Plugin
  * Copyright (c) 2003-2007 Paul Lesneiwski <paul@squirrelmail.org>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage vlogin
  *
  */


/**
  * Register this plugin with SquirrelMail
  *
  */
function squirrelmail_plugin_init_vlogin() {

   global $squirrelmail_plugin_hooks;


   // manipulation of given username
   //
   $squirrelmail_plugin_hooks['login_before']['vlogin']               = 'vlogin_domain';

   $squirrelmail_plugin_hooks['login_verified']['vlogin']             = 'vlogin_save_original';


   // control over display of user configuration options
   //
   $squirrelmail_plugin_hooks['optpage_loadhook_display']['vlogin']   = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_personal']['vlogin']  = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_folder']['vlogin']    = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_highlight']['vlogin'] = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_order']['vlogin']     = 'vlogin_display_options';


   // configuration validation
   //
   $squirrelmail_plugin_hooks['configtest']['vlogin']                 = 'vlogin_check_configuration';


   // helps catch config overrides when not already set up in 1.4.x
   //
   $squirrelmail_plugin_hooks['loading_constants']['vlogin'] = 'vlogin_overrideSmConfig';
   $squirrelmail_plugin_hooks['logout']['vlogin']            = 'vlogin_overrideSmConfig';


   // just register multilogin on config override; helps catch 
   // config overrides when not already set up in 1.5.x...  only
   // actually needed on login.php and signout.php
   //
   $squirrelmail_plugin_hooks['config_override']['vlogin'] = 'vlogin_overrideSmConfig';


   // this code only works pre 1.5.2 and is deprecated; users should
   // migrate to $useSessionBased anyway (this is an attempt at a poor-
   // person's $useSessionBased with no source patch)... 1.5.2 no 
   // longer requires patching to use $useSessionBased
   //
   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   load_vlogin_config();
   global $useSessionBased;
   if (!$useSessionBased)
   {

      include_once(SM_PATH . 'plugins/vlogin/functions.php');
      overrideSmConfig(array('squirrelmail_plugin_init_vlogin')); // dummy hook name

   }

}



/** @ignore */
if (!defined('SM_PATH'))
   define('SM_PATH', '../');



/**
  * Returns info about this plugin
  *
  */
function vlogin_info()
{

   return array(
                 'english_name' => 'Login Manager',
                 'version' => '3.9.2',
                 'required_sm_version' => '1.2.7',
                 'requires_configuration' => 0,
                 'required_plugins' => array(
                                               'compatibility' => '2.0.5',
                                            ),
                 'requires_source_patch' => 0,
                 'required_php_version' => '4.0.6',
                 'summary' => 'Helps manage and manipulate usernames given at login time, and allows the use of different SquirrelMail settings (such as login page image, or IMAP server) for each domain, each user, or each user group',
                 'details' => 'VLogin is a plugin for SquirrelMail that:'
         . '<ul><li> helps manage and manipulate usernames given at login time<br /><br />' 
         . '<li> allows the use of different SquirrelMail settings (such as login page image, or IMAP server) for each domain, each user, or each user group</ul>'
         . 'Vlogin is both useful if you just need to make sure that usernames given on the login page are consistent and/or if you host more than one domain and wish to customize SquirrelMail for each domain but do not want to install and manage a separate SquirrelMail installation for each one.<br /><br />' 
         . 'Vlogin is also meant to help your users: if your user accounts are of the form "jose@example.net", it allows users to log in by only typing "jose" in the username field.<br /><br />' 
         . 'Finally, Vlogin is capable of supporting fairly complex systems where the SquirrelMail settings, appearance, access levels, and behaviors are based on username, domain or "service level" (user group).<br /><br />' 
         . 'Despite the plugin name, even single-domain servers may find very useful functionality herein, such as username consistency/simplicity, or per-user settings or "service level" user settings groups, etc.<br /><br />' 
         . 'Some of Vlogin\'s helpful features include:'
         . '<ul><li> make sure all usernames given on login page do not have any domain portion in them'
         . '<li> make sure all usernames given on login page have the SquirrelMail default domain appended to them'
         . '<li> make sure all usernames given on login page have the domain that corresponds to the domain in the URL of the login page appended to them'
         . '<li> allow users to log in with just a "user" when in fact their IMAP login might be something like "username@domain.com"'
         . '<li> show a different image on the login page for each of your domains'
         . '<li> change most any SquirrelMail configuration setting on a per-domain per-service level, or even per-user basis'
         . '<li> access a sendmail-style virtual users table'
         . '<li> change IMAP servers (or any other settings) on a per-domain, per-service level, or even on a per-user basis'
         . '<li> enable or disable certain plugins on a per-domain, per-service level or per-user basis'
         . '<li> disable certain option page items on a per-domain, per-service level or per-user basis'
         . '<li> dealias Qmail/Vpopmail aliased domains'
         . '<li> domain name translation'
         . '<li> access per-domain, per-service level or per-user settings stored in a SQL database'
         . '<li> much more...</ul>',
               );

}



/**
  * Returns version info about this plugin
  *
  */
function vlogin_version() 
{

   $info = vlogin_info();
   return $info['version'];

}



/**
  * Remap Username When Logging In
  *
  */
function vlogin_domain($args) 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_domain_do($args);

}



/**
  * Save original username used to log in
  *
  */
function vlogin_save_original() 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_save_original_do();

}



/**
  * Allows control over which options are displayed on options pages
  *
  */
function vlogin_display_options() 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_display_options_do();

}



/**
  * Override Default Config Values
  *
  */
function vlogin_overrideSmConfig($args) 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   overrideSmConfig($args);

}



/**
  * Validate that this plugin is configured correctly
  *
  * @return boolean Whether or not there was a
  *                 configuration error for this plugin.
  *
  */
function vlogin_check_configuration()
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   return vlogin_check_configuration_do();

}

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvlogin-3.10-1.2.7.tar.gz: vlogin/setup.php <==
<?php

/**
  * SquirrelMail Login Manager Plugin
  * Copyright (c) 2002-2008 Paul Lesniewski <paul@squirrelmail.org>
  * Copyright (c) 2001 Ryan Orth <snubber-sm@seahat.com>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * @package plugins
  * @subpackage vlogin
  *
  */


/**
  * Register this plugin with SquirrelMail
  *
  */
function squirrelmail_plugin_init_vlogin()
{

   global $squirrelmail_plugin_hooks;


   // manipulation of given username
   //
   $squirrelmail_plugin_hooks['login_before']['vlogin']
      = 'vlogin_domain';

   $squirrelmail_plugin_hooks['login_verified']['vlogin']
      = 'vlogin_save_original';


   // control over display of user configuration options
   //
   $squirrelmail_plugin_hooks['optpage_loadhook_display']['vlogin']
      = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_personal']['vlogin']
      = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_folder']['vlogin']
      = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_highlight']['vlogin']
      = 'vlogin_display_options';
   $squirrelmail_plugin_hooks['optpage_loadhook_order']['vlogin']
      = 'vlogin_display_options';


   // configuration validation
   //
   $squirrelmail_plugin_hooks['configtest']['vlogin']
      = 'vlogin_check_configuration';


   // helps catch config overrides when not already set up in 1.4.x
   // (note that we used to use the "logout" hook here too, but the
   // "loading_constants" hook should cover for that one)
   //
   $squirrelmail_plugin_hooks['loading_constants']['vlogin']
      = 'vlogin_overrideSmConfig';


   // helps catch config overrides when not already set up in 1.4.x and 1.5.x
   //
   $squirrelmail_plugin_hooks['logout_error']['vlogin']
      = 'vlogin_overrideSmConfig';


   // this is main settings override point in 1.5.2; on all but signout.php
   // and login.php, it merely calls to the multilogin override function
   // that gets the overrides that are already stored in the PHP session
   //
   // $squirrelmail_plugin_hooks['config_override']['vlogin']
   $squirrelmail_plugin_hooks['prefs_backend']['vlogin']
      = 'vlogin_overrideSmConfig';


   // this code only works pre 1.5.2 and is deprecated; users should
   // migrate to $useSessionBased anyway (this is an attempt at a poor-
   // person's $useSessionBased with no source patch)... 1.5.2 no 
   // longer requires patching to use $useSessionBased
   //
   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   load_vlogin_config();
   global $useSessionBased;
   if (!$useSessionBased && !check_sm_version(1, 5, 2))
   {
      include_once(SM_PATH . 'plugins/vlogin/functions.php');
      overrideSmConfig(array('squirrelmail_plugin_init_vlogin')); // dummy hook name
   }

}



/**
  * Returns info about this plugin
  *
  */
function vlogin_info()
{

   return array(
                 'english_name' => 'Login Manager',
                 'authors' => array(
                    'Paul Lesniewski' => array(
                       'email' => 'paul@squirrelmail.org',
                       'sm_site_username' => 'pdontthink',
                    ),
                 ),
                 'version' => '3.10',
                 'required_sm_version' => '1.2.7',
                 'requires_configuration' => 0,
                 'required_plugins' => array(
                    'compatibility' => array(
                       'version' => '2.0.12',
                       'activate' => FALSE,
                    )
                 ),
                 'requires_source_patch' => 0,
                 'required_php_version' => '4.0.6',
                 'summary' => 'Helps manage and manipulate usernames given at login time, and allows the use of different SquirrelMail settings (such as login page image, or IMAP server) for each domain, each user, or each user group',
                 'details' => 'VLogin is a plugin for SquirrelMail that:'
         . '<ul><li> helps manage and manipulate usernames given at login time<br /><br />' 
         . '<li> allows the use of different SquirrelMail settings (such as login page image, or IMAP server) for each domain, each user, or each user group</ul>'
         . 'Vlogin is both useful if you just need to make sure that usernames given on the login page are consistent and/or if you host more than one domain and wish to customize SquirrelMail for each domain but do not want to install and manage a separate SquirrelMail installation for each one.<br /><br />' 
         . 'Vlogin is also meant to help your users: if your user accounts are of the form "jose@example.net", it allows users to log in by only typing "jose" in the username field.<br /><br />' 
         . 'Finally, Vlogin is capable of supporting fairly complex systems where the SquirrelMail settings, appearance, access levels, and behaviors are based on username, domain or "service level" (user group).<br /><br />' 
         . 'Despite the plugin name, even single-domain servers may find very useful functionality herein, such as username consistency/simplicity, or per-user settings or "service level" user settings groups, etc.<br /><br />' 
         . 'Some of Vlogin\'s helpful features include:'
         . '<ul><li> make sure all usernames given on login page do not have any domain portion in them'
         . '<li> make sure all usernames given on login page have the SquirrelMail default domain appended to them'
         . '<li> make sure all usernames given on login page have the domain that corresponds to the domain in the URL of the login page appended to them'
         . '<li> allow users to log in with just a "user" when in fact their IMAP login might be something like "username@domain.com"'
         . '<li> show a different image on the login page for each of your domains'
         . '<li> change most any SquirrelMail configuration setting on a per-domain per-service level, or even per-user basis'
         . '<li> access a sendmail, postfix or qmail style virtual users table'
         . '<li> change IMAP servers (or any other settings) on a per-domain, per-service level, or even on a per-user basis'
         . '<li> enable or disable certain plugins on a per-domain, per-service level or per-user basis'
         . '<li> disable certain option page items on a per-domain, per-service level or per-user basis'
         . '<li> dealias Qmail/Vpopmail aliased domains'
         . '<li> domain name translation'
         . '<li> access per-domain, per-service level or per-user settings stored in a SQL database'
         . '<li> much more...</ul>',
               );

}



/**
  * Returns version info about this plugin
  *
  */
function vlogin_version() 
{

   $info = vlogin_info();
   return $info['version'];

}



/**
  * Remap Username When Logging In
  *
  */
function vlogin_domain($args) 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_domain_do($args);

}



/**
  * Save original username used to log in
  *
  */
function vlogin_save_original() 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_save_original_do();

}



/**
  * Allows control over which options are displayed on options pages
  *
  */
function vlogin_display_options() 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   vlogin_display_options_do();

}



/**
  * Override Default Config Values
  *
  */
function vlogin_overrideSmConfig($args) 
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   overrideSmConfig($args);

}



/**
  * Validate that this plugin is configured correctly
  *
  * @return boolean Whether or not there was a
  *                 configuration error for this plugin.
  *
  */
function vlogin_check_configuration()
{

   include_once(SM_PATH . 'plugins/vlogin/functions.php');
   return vlogin_check_configuration_do();

}
